==> allianceauth_corptools-2.9.2.tar.gz: allianceauth_corptools-2.9.2/frontend/src/Pages/Corp/Wallet.tsx <==
import { useTranslation } from "react-i18next";
import { useState } from "react";
import CorpSelect from "../../Components/Corporation/CorporationSelect";
import RefTypeSelect from "../../Components/Corporation/RefTypeSelect";
import CorporationWalletTable from "../../Components/Corporation/WalletTable";
import { CorpLoader } from "../../Components/Loaders/loaders";
import CorpDivisions from "../../Components/Corporation/Divisions";

const CorporationWallets = () => {
  const { t } = useTranslation();

  const [corporationID, setCorporation] = useState<number>(0);
  const [refTypes, setRefs] = useState("");

  const RefsToState = (entry: any) => {
    let values = entry.map((o: any) => {
      return o.value;
    });
    setRefs(values.sort().join(","));
  };

  return (
    <>
      <div className="m-3 d-flex align-items-center my-1">
        <h6 className="me-1">{t("Corporation Filter")}</h6>
        <div className="flex-grow-1">
          <CorpSelect {...{ setCorporation }} />
        </div>
      </div>
      <div className="m-3 d-flex align-items-center my-1">
        <h6 className="me-1">{t("Ref Type Filter")}</h6>
        <div className="flex-grow-1">
          <RefTypeSelect setFilter={RefsToState} />
        </div>
      </div>
      <div className="d-flex flex-column align-items-center my-1">
        <h5>{t("Division Balances")}</h5>
        <CorpDivisions corporationID={corporationID} />
      </div>
      {corporationID ? (
        refTypes == "" ? (
          <CorpLoader title={t("Select Ref Types")} />
        ) : (
          <CorporationWalletTable {...{ corporationID, refTypes }} />
        )
      ) : (
        <CorpLoader />
      )}
    </>
  );
};

export default CorporationWallets;

==> allianceauth_corptools-2.10.7.tar.gz: allianceauth_corptools-2.10.7/frontend/src/Pages/Corp/Wallet.tsx <==
import { useTranslation } from "react-i18next";
import { useState } from "react";
import CorpSelect from "../../Components/Corporation/CorporationSelect";
import RefTypeSelect from "../../Components/Corporation/RefTypeSelect";
import CorporationWalletTable from "../../Components/Corporation/WalletTable";
import { CorpLoader } from "../../Components/Loaders/loaders";
import CorpDivisions from "../../Components/Corporation/Divisions";

const CorporationWallets = () => {
  const { t } = useTranslation();
  const [corporationID, setCorporation] = useState<number>(0);
  const [refTypes, setRefs] = useState("");
  return (
    <>
      <div className="m-3 d-flex align-items-center my-1">
        <h6 className="me-1">{t("Corporation Filter")}</h6>
        <div className="flex-grow-1">
          <CorpSelect {...{ setCorporation }} />
        </div>
      </div>
      <div className="m-3 d-flex align-items-center my-1">
        <h6 className="me-1">{t("Ref Type Filter")}</h6>
        <div className="flex-grow-1">
          <RefTypeSelect setFilter={setRefs} preFill={refTypes} />
        </div>
      </div>
      <div className="d-flex flex-column align-items-center my-1">
        <h5>{t("Division Balances")}</h5>
        <CorpDivisions corporationID={corporationID} />
      </div>
      {corporationID ? (
        refTypes == "" ? (
          <CorpLoader title={t("Select Ref Types")} />
        ) : (
          <CorporationWalletTable {...{ corporationID, refTypes }} />
        )
      ) : (
        <CorpLoader />
      )}
    </>
  );
};

export default CorporationWallets;
